#include "protocol.h"
#include <sys/types.h>
#include <sys/socket.h>
#include <syslog.h>
#include <string.h>
#include <stdio.h>

int send_cmd(struct protocol * cmd, int fd) {
    int ret;
    syslog(LOG_DEBUG, "DEBUG: Sending render cmd with protocol version %i\n", cmd->ver);
    switch (cmd->ver) { 
    case 1:
        ret = send(fd, cmd, sizeof(struct protocol_v1), 0); 
        break; 
    case 2:  
        ret = send(fd, cmd, sizeof(struct protocol_v2), 0); 
        break; 
    case 3: 
        ret = send(fd, cmd, sizeof(struct protocol), 0); 
        break; 
    }
    if ((ret != sizeof(struct protocol)) && (ret != sizeof(struct protocol_v2)) && (ret != sizeof(struct protocol_v1))) {
        perror("send error");
    }
    return ret;
}

int recv_cmd(struct protocol * cmd, int fd) {
    int ret, ret2;
    memset(cmd,0,sizeof(*cmd));
    ret = recv(fd, cmd, sizeof(struct protocol_v1), MSG_DONTWAIT);
    if (ret < 1) {
        return -1;
    } else if (ret < sizeof(struct protocol_v1)) {
        return 0;
    }
    syslog(LOG_DEBUG, "DEBUG: Got incoming request with protocol version %i\n", cmd->ver); 
    switch (cmd->ver) { 
    case 2: ret2 = recv(fd, ((void*)cmd) + sizeof(struct protocol_v1), sizeof(struct protocol_v2) - sizeof(struct protocol_v1), MSG_DONTWAIT); 
        break; 
    case 3: ret2 = recv(fd, ((void*)cmd) + sizeof(struct protocol_v1), sizeof(struct protocol) - sizeof(struct protocol_v1), MSG_DONTWAIT); 
        break; 
    }
    
    if (ret2 < 1) {
        syslog(LOG_WARNING, "WARNING: Socket prematurely closed: %i\n", fd); 
        return -1;
    }
    
    ret += ret2;
    
    if ((ret == sizeof(struct protocol)) || (ret == sizeof(struct protocol_v1)) || (ret == sizeof(struct protocol_v2))) {
        return ret;
    }
    syslog(LOG_WARNING, "WARNING: Socket read wrong number of bytes: %i -> %li, %li\n", ret, sizeof(struct protocol_v2), sizeof(struct protocol)); 
    return 0;
}
